var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import CodiceFiscale from 'codice-fiscale-js';
import { createStyles, withStyles } from '@material-ui/core/styles';
import IconButton from '@material-ui/core/IconButton';
import ErrorIcon from '@material-ui/icons/ErrorOutline';
import CalcIcon from '@material-ui/icons/FlashOn';
import Tooltip from '@material-ui/core/Tooltip';
import { Gender, TextField, TooltipIcon } from '../index';
import { DateUtils } from '../utils';
import Strings from './FiscalCodeTextField.strings';
var styles = function (theme) {
    return createStyles({
        input: {
            textTransform: 'uppercase',
        },
        labelValue: {
            textTransform: 'uppercase',
        },
        iconButton: {
            padding: 0,
            '&:hover': {
                backgroundColor: 'inherit',
            },
        },
    });
};
var FISCAL_CODE_LENGTH = 16;
var FiscalCodeTextField = /** @class */ (function (_super) {
    __extends(FiscalCodeTextField, _super);
    function FiscalCodeTextField(props) {
        var _this = _super.call(this, props) || this;
        _this.hasError = function () {
            var value = _this.props.value;
            if (value && value.length !== FISCAL_CODE_LENGTH) {
                return true;
            }
            return false;
        };
        _this.canCalc = function () {
            var personInfo = _this.props.personInfo;
            if (personInfo === undefined) {
                return false;
            }
            if (personInfo.firstName === undefined || personInfo.firstName.trim().length === 0) {
                return false;
            }
            if (personInfo.lastName === undefined || personInfo.lastName.trim().length === 0) {
                return false;
            }
            if (personInfo.gender === undefined) {
                return false;
            }
            if (personInfo.birthDate === undefined) {
                return false;
            }
            if (personInfo.birthCity === undefined || personInfo.birthCity.trim().length === 0) {
                return false;
            }
            return true;
        };
        _this.calc = function () {
            if (!_this.canCalc()) {
                return undefined;
            }
            var personInfo = _this.props.personInfo || {};
            var birthDate = DateUtils.toMoment(personInfo.birthDate);
            var fcData = {
                name: personInfo.firstName,
                surname: personInfo.lastName,
                gender: personInfo.gender === Gender.Male ? 'M' : 'F',
                day: birthDate.date(),
                month: birthDate.month() + 1,
                year: birthDate.year(),
                birthplace: personInfo.birthCity,
                birthplaceProvincia: personInfo.birthProvince,
            };
            try {
                return CodiceFiscale.compute(fcData);
            }
            catch (err) {
                return undefined;
            }
            return undefined;
        };
        _this.handleOnCalcButtonClick = function () {
            var _a = _this.props, onChange = _a.onChange, onCalcClick = _a.onCalcClick;
            if (!onChange) {
                return;
            }
            if (onCalcClick) {
                onCalcClick();
            }
            var fc = _this.calc();
            if (fc !== undefined) {
                onChange({
                    // @ts-ignore
                    target: {
                        name: _this.props.name || '',
                        value: fc,
                    },
                });
            }
        };
        _this.handleOnChange = function (event) {
            var onChange = _this.props.onChange;
            var value = event.target.value;
            if (value.length > FISCAL_CODE_LENGTH || !onChange) {
                return;
            }
            onChange(event);
        };
        return _this;
    }
    FiscalCodeTextField.prototype.render = function () {
        var _a = this.props, value = _a.value, personInfo = _a.personInfo, withCalc = _a.withCalc, classes = _a.classes, endAdornment = _a.endAdornment, TooltipProps = _a.TooltipProps, restProps = __rest(_a, ["value", "personInfo", "withCalc", "classes", "endAdornment", "TooltipProps"]);
        var hasError = this.hasError();
        var endAdornmentContainer = undefined;
        if (withCalc) {
            var fc = this.calc();
            if (fc !== undefined) {
                endAdornmentContainer = (React.createElement(Tooltip, __assign({ title: Strings.calcHelper }, TooltipProps),
                    React.createElement("div", { onClick: this.handleOnCalcButtonClick }, endAdornment ? (endAdornment) : (React.createElement(IconButton, { className: classes.iconButton },
                        React.createElement(CalcIcon, null))))));
            }
        }
        else if (hasError) {
            endAdornmentContainer = React.createElement(TooltipIcon, { Icon: ErrorIcon, message: Strings.errorMessage });
        }
        return (React.createElement(TextField, __assign({}, restProps, { value: value, endAdornment: endAdornmentContainer, type: "text", onChange: this.handleOnChange, classes: {
                input: value && value.length > 0 ? classes.input : undefined,
                labelValue: classes.labelValue,
            } })));
    };
    return FiscalCodeTextField;
}(React.Component));
export default withStyles(styles)(FiscalCodeTextField);
//# sourceMappingURL=FiscalCodeTextField.js.map