var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import * as classNames from 'classnames';
import { get } from 'lodash';
import { createStyles, withStyles } from '@material-ui/core/styles';
import FormHelperText from '@material-ui/core/FormHelperText';
import Typography from '@material-ui/core/Typography';
import { AddressForm, LabelField, TextField, AutocompleteTextField, } from '../index';
import { LocationUtils } from '../utils';
import Strings from './LocationForm.strings';
var styles = function (theme) {
    var _a;
    return createStyles({
        root: {
            display: 'flex',
            flexDirection: 'column',
        },
        addressForm: {
            marginBottom: theme.spacing(2),
        },
        inputContainer: (_a = {
                width: '100%',
                display: 'flex',
                flexDirection: 'row',
                '& $input:not(:last-of-type)': {
                    marginRight: theme.spacing(2),
                }
            },
            _a[theme.breakpoints.down(theme.breakpoints.values.sm)] = {
                flexDirection: 'column',
                alignItems: 'stretch',
                '& $input:not(:last-of-type)': {
                    marginRight: 0,
                    marginBottom: theme.spacing(2),
                },
            },
            _a),
        input: {
            flex: 1,
        },
        label: {},
    });
};
var LocationForm = /** @class */ (function (_super) {
    __extends(LocationForm, _super);
    function LocationForm() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.hasError = function () {
            var _a = _this.props, error = _a.error, locationError = _a.locationError;
            if (error) {
                return true;
            }
            // No error and no location error
            if (!locationError) {
                return false;
            }
            return (!!locationError.address ||
                !!locationError.city ||
                !!locationError.province ||
                !!locationError.fraction ||
                !!locationError.state);
        };
        _this.handleOnChange = function (event) {
            var _a = _this.props, value = _a.value, withState = _a.withState, withFraction = _a.withFraction, withCity = _a.withCity, withProvince = _a.withProvince, onChange = _a.onChange;
            if (!onChange) {
                return;
            }
            var field = event.target.name;
            var v = event.target.value;
            var val;
            if (field === 'fraction') {
                val = v;
            }
            else {
                val = {
                    name: v,
                };
            }
            var nextValue = __assign({}, value);
            nextValue[field] = val;
            if (!withCity) {
                delete nextValue.city;
            }
            if (!withProvince) {
                delete nextValue.province;
            }
            if (!withFraction) {
                delete nextValue.fraction;
            }
            if (!withState) {
                delete nextValue.state;
            }
            onChange(nextValue, [field]);
        };
        _this.handleOnClear = function (event) {
            var _a = _this.props, value = _a.value, onChange = _a.onChange, onClear = _a.onClear;
            var field = event.target.name;
            var v = __assign({}, value);
            delete v[field];
            if (Object.keys(v).length === 0 && onClear) {
                onClear(event, [field]);
            }
            else if (onChange) {
                onChange(v, [field]);
            }
        };
        _this.handleOnAddressChange = function (address, addressFields) {
            var _a = _this.props, value = _a.value, onChange = _a.onChange;
            if (!onChange) {
                return;
            }
            var fields = undefined;
            if (addressFields !== undefined) {
                fields = addressFields.map(function (f) { return _this.props.addressFieldName + "." + f; });
            }
            onChange(__assign(__assign({}, value), { address: address }), fields);
        };
        _this.handleOnAddressClear = function (event) {
            var _a = _this.props, value = _a.value, onChange = _a.onChange, onClear = _a.onClear;
            var v = __assign({}, value);
            delete v.address;
            var fields = [_this.props.addressFieldName];
            if (event.target.name) {
                fields.push(_this.props.addressFieldName + "." + event.target.name);
            }
            if (Object.keys(v).length === 0 && onClear) {
                onClear(event, fields);
            }
            else if (onChange) {
                onChange(v, fields);
            }
        };
        _this.handleOnSuggestionSelected = function (suggestion, field) {
            var _a = _this.props, value = _a.value, withState = _a.withState, withFraction = _a.withFraction, withCity = _a.withCity, withProvince = _a.withProvince, onChange = _a.onChange;
            if (!onChange) {
                return;
            }
            var nextValue = suggestion;
            if (!withCity) {
                delete nextValue.city;
            }
            if (!withProvince) {
                delete nextValue.province;
            }
            if (!withFraction) {
                delete nextValue.fraction;
            }
            if (!withState) {
                delete nextValue.state;
            }
            var fields = [];
            if (get(value, 'city.name') !== get(nextValue, 'city.name')) {
                fields.push('city');
            }
            if (get(value, 'state.name') !== get(nextValue, 'state.name')) {
                fields.push('state');
            }
            if (get(value, 'province.name') !== get(nextValue, 'province.name')) {
                fields.push('province');
            }
            onChange(nextValue, fields);
        };
        _this.renderCityTextField = function () {
            var _a = _this.props, withCity = _a.withCity, usePlaceholder = _a.usePlaceholder, error = _a.error, locationHelper = _a.locationHelper, locationError = _a.locationError, variant = _a.variant, value = _a.value, searchParams = _a.searchParams, onFetchCitySuggestions = _a.onFetchCitySuggestions, classes = _a.classes;
            if (!withCity) {
                return null;
            }
            var helpers = locationHelper || {};
            var city = value ? value.city || {} : {};
            if (onFetchCitySuggestions) {
                return (React.createElement(AutocompleteTextField, { name: "city", placeholder: usePlaceholder ? Strings.city : undefined, label: !usePlaceholder ? Strings.city : undefined, helperText: helpers.city, value: city.name || '', error: error || locationError.city, variant: variant, loadingVariant: "icon", withSearchParams: true, searchParams: searchParams || value, searchParamsFields: ['city.name'], suggestionLabelField: "city.name", fetchSuggestions: onFetchCitySuggestions, onChange: _this.handleOnChange, onClear: _this.handleOnClear, onSuggestionSelected: _this.handleOnSuggestionSelected, className: classes.input }));
            }
            return (React.createElement(TextField, { name: "city", placeholder: usePlaceholder ? Strings.city : undefined, label: !usePlaceholder ? Strings.city : undefined, helperText: helpers.city, value: city.name || '', error: error || locationError.city, variant: variant, onChange: _this.handleOnChange, onClear: _this.handleOnClear, className: classes.input }));
        };
        return _this;
    }
    LocationForm.prototype.render = function () {
        var _a = this.props, label = _a.label, addressLabel = _a.addressLabel, value = _a.value, mode = _a.mode, usePlaceholder = _a.usePlaceholder, helperText = _a.helperText, error = _a.error, addressFieldName = _a.addressFieldName, locationError = _a.locationError, locationHelper = _a.locationHelper, withProvince = _a.withProvince, withFraction = _a.withFraction, withState = _a.withState, variant = _a.variant, LabelFieldProps = _a.LabelFieldProps, className = _a.className, classes = _a.classes;
        if (mode === 'label') {
            return (React.createElement(LabelField, __assign({}, LabelFieldProps, { label: label, value: LocationUtils.locationToString(value), className: className })));
        }
        var helpers = locationHelper || {};
        var province = value ? value.province || {} : {};
        var state = value ? value.state || {} : {};
        return (React.createElement("div", { className: classNames(classes.root, className) },
            label && (React.createElement(Typography, { gutterBottom: true, className: classes.label }, label)),
            React.createElement(AddressForm, { name: addressFieldName, label: addressLabel, value: value.address, usePlaceholder: usePlaceholder, variant: variant, error: error, addressError: locationError.address, addressHelper: helpers.address, onChange: this.handleOnAddressChange, onClear: this.handleOnAddressClear, className: classes.addressForm }),
            React.createElement("div", { className: classes.inputContainer },
                this.renderCityTextField(),
                withProvince && (React.createElement(TextField, { name: "province", placeholder: usePlaceholder ? Strings.province : undefined, label: !usePlaceholder ? Strings.province : undefined, helperText: helpers.province, value: province.name || '', error: error || locationError.province, variant: variant, onChange: this.handleOnChange, onClear: this.handleOnClear, className: classes.input })),
                withFraction && (React.createElement(TextField, { name: "fraction", placeholder: usePlaceholder ? Strings.fraction : undefined, label: !usePlaceholder ? Strings.fraction : undefined, helperText: helpers.fraction, value: value.fraction || '', error: error || locationError.fraction, variant: variant, onChange: this.handleOnChange, onClear: this.handleOnClear, className: classes.input })),
                withState && (React.createElement(TextField, { name: "state", placeholder: usePlaceholder ? Strings.state : undefined, label: !usePlaceholder ? Strings.state : undefined, helperText: helpers.state, value: state.name || '', error: error || locationError.state, variant: variant, onChange: this.handleOnChange, onClear: this.handleOnClear, className: classes.input }))),
            helperText && React.createElement(FormHelperText, { error: this.hasError() }, helperText)));
    };
    LocationForm.defaultProps = {
        mode: 'input',
        value: {},
        locationError: {},
        withCity: true,
        withFraction: false,
        withProvince: false,
        withState: true,
        addressFieldName: 'address',
    };
    return LocationForm;
}(React.Component));
export default withStyles(styles)(LocationForm);
//# sourceMappingURL=LocationForm.js.map