var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { withStyles, createStyles } from '@material-ui/core/styles';
import Strings from './PaymentSourcesSelect.strings';
import { StripeProvider } from 'react-stripe-elements';
import CreditCardForm from '../CreditCardForm/CreditCardForm';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import DeleteIcon from '@material-ui/icons/Delete';
import Button from '../Button';
import ConfirmButton from '../ConfirmButton';
import AlertDialog from '../AlertDialog';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import Radio from '@material-ui/core/Radio';
import Tooltip from '@material-ui/core/Tooltip';
import RadioGroup from '@material-ui/core/RadioGroup';
var styles = function (theme) {
    var _a, _b, _c, _d, _e, _f;
    return createStyles({
        root: {
            display: 'flex',
            flexDirection: 'column',
        },
        radioGroup: {
            padding: theme.spacing(2),
        },
        formControlLabel: (_a = {},
            _a[theme.breakpoints.down(550)] = {
                flexDirection: 'column',
            },
            _a),
        label: (_b = {
                display: 'flex',
                flexDirection: 'row',
                alignItems: 'center'
            },
            _b[theme.breakpoints.down(550)] = {
                flexDirection: 'column',
            },
            _b),
        brand: (_c = {
                display: 'flex',
                flexDirection: 'row',
                alignItems: 'center',
                marginRight: theme.spacing(2)
            },
            _c[theme.breakpoints.down(550)] = {
                flexDirection: 'column',
                marginRight: 0,
            },
            _c),
        brandIcon: (_d = {
                marginRight: theme.spacing(2)
            },
            _d[theme.breakpoints.down(550)] = {
                marginRight: 0,
            },
            _d),
        expirationDate: (_e = {
                marginLeft: theme.spacing(2)
            },
            _e[theme.breakpoints.down(550)] = {
                marginRight: 0,
            },
            _e),
        addPaymentSourceButton: (_f = {
                alignSelf: 'flex-start'
            },
            _f[theme.breakpoints.down(550)] = {
                alignSelf: 'unset',
            },
            _f),
        cardItemDelete: {
            marginLeft: theme.spacing(2),
        },
    });
};
var PaymentSourcesSelect = /** @class */ (function (_super) {
    __extends(PaymentSourcesSelect, _super);
    function PaymentSourcesSelect(props) {
        var _this = _super.call(this, props) || this;
        _this.changeFormVisibility = function (isVisible) {
            _this.setState({ showAddPaymentSourceForm: isVisible }, function () {
                if (_this.props.onNewCardFormVisibilityChange) {
                    _this.props.onNewCardFormVisibilityChange(isVisible);
                }
            });
        };
        _this.handleSourceChange = function (event) {
            var selectedSourceId = event.target.value;
            var selectedSource = _this.props.paymentSources.find(function (p) { return p.id === selectedSourceId; });
            _this.setState({
                selectedSourceId: selectedSourceId,
            }, function () {
                if (_this.props.onChange) {
                    _this.props.onChange(selectedSource || undefined);
                }
            });
        };
        _this.handleAddPaymentSourceClick = function () {
            _this.changeFormVisibility(true);
        };
        _this.handleAddPaymentSourceClose = function () {
            _this.changeFormVisibility(false);
        };
        _this.handlePaymentSourceAdded = function (paymentSource) {
            if (_this.props.onPaymentSourceAdded) {
                _this.props.onPaymentSourceAdded(paymentSource);
            }
            _this.changeFormVisibility(false);
        };
        _this.handleDeletePaymentSourceClick = function (paymentSource) { return function () {
            if (_this.props.onPaymentSourceDeleted) {
                _this.props.onPaymentSourceDeleted(paymentSource);
            }
        }; };
        _this.handleAlertClose = function () {
            _this.setState({ alertOpen: false });
        };
        _this.renderBrandIcon = function (brand) {
            var classes = _this.props.classes;
            if (!brand) {
                return null;
            }
            var iconName;
            switch (brand.toLowerCase()) {
                case 'mastercard':
                    iconName = 'cc-mastercard';
                    break;
                case 'visa':
                    iconName = 'cc-visa';
                    break;
                case 'american express':
                    iconName = 'cc-amex';
                    break;
                case 'jcb':
                    iconName = 'cc-jcb';
                    break;
                case 'discover':
                    iconName = 'cc-discover';
                    break;
                case 'diners':
                    iconName = 'cc-diners-club';
                    break;
                default:
                    break;
            }
            return (React.createElement("span", { className: classes.brand },
                iconName ? (React.createElement(FontAwesomeIcon, { className: classes.brandIcon, icon: ['fab', iconName], size: "2x" })) : null,
                brand));
        };
        _this.renderCardItem = function (paymentSource) {
            var classes = _this.props.classes;
            var showAddPaymentSourceForm = _this.state.showAddPaymentSourceForm;
            if (!paymentSource.card) {
                return null;
            }
            var label = (React.createElement("span", { id: "card-item-label", className: classes.label },
                _this.renderBrandIcon(paymentSource.card.brand), "**** **** **** " + paymentSource.card.last4,
                React.createElement("span", { className: classes.expirationDate }, Strings.formatString(Strings.expireAt, {
                    expirationDate: paymentSource.card.expireMonth + "/" + paymentSource.card.expireYear,
                })),
                React.createElement(ConfirmButton, { id: "card-item-delete", version: "icon", title: Strings.deletePaymentSourceConfirm.title, message: Strings.deletePaymentSourceConfirm.message, onConfirm: _this.handleDeletePaymentSourceClick(paymentSource), disabled: showAddPaymentSourceForm, className: classes.cardItemDelete },
                    React.createElement(Tooltip, { title: Strings.deletePaymentSource },
                        React.createElement(DeleteIcon, null)))));
            return (React.createElement(FormControlLabel, { key: "paymentSource_" + paymentSource.id, className: classes.formControlLabel, value: paymentSource.id, control: React.createElement(Radio, { color: "primary", disabled: showAddPaymentSourceForm }), label: label }));
        };
        _this.renderCardRadioGroup = function () {
            var _a = _this.props, classes = _a.classes, paymentSources = _a.paymentSources;
            var preferredSource = paymentSources ? paymentSources.find(function (p) { return !!p.isPreferred; }) : null;
            var value = _this.state.selectedSourceId
                ? _this.state.selectedSourceId
                : preferredSource
                    ? preferredSource.id
                    : undefined;
            if (paymentSources && paymentSources.length === 0) {
                return null;
            }
            return (React.createElement(RadioGroup, { className: classes.radioGroup, value: value || '', onChange: _this.handleSourceChange }, paymentSources.map(function (p) { return _this.renderCardItem(p); })));
        };
        _this.renderPaymentForm = function () {
            var _a = _this.props, paymentSources = _a.paymentSources, isInTestMode = _a.isInTestMode, stripeApiKey = _a.stripeApiKey, PayButtonProps = _a.PayButtonProps;
            var showAddPaymentSourceForm = _this.state.showAddPaymentSourceForm;
            var hasPaymentSources = paymentSources && paymentSources.length > 0;
            if (isInTestMode || (!showAddPaymentSourceForm && hasPaymentSources)) {
                return null;
            }
            return (React.createElement(StripeProvider, { apiKey: stripeApiKey },
                React.createElement(CreditCardForm, { disableCloseButton: !hasPaymentSources, onCardSaved: _this.handlePaymentSourceAdded, onClose: _this.handleAddPaymentSourceClose, PayButtonProps: PayButtonProps })));
        };
        _this.state = {
            showAddPaymentSourceForm: false,
            alertOpen: false,
        };
        return _this;
    }
    PaymentSourcesSelect.prototype.render = function () {
        var _a = this.props, classes = _a.classes, paymentSources = _a.paymentSources, AddCardButtonProps = _a.AddCardButtonProps;
        var _b = this.state, showAddPaymentSourceForm = _b.showAddPaymentSourceForm, alertOpen = _b.alertOpen;
        var addPaymentSourceButton = !showAddPaymentSourceForm && paymentSources && paymentSources.length > 0 ? (React.createElement(Button, __assign({ id: "add-source-payment", variant: "text", color: "primary", onClick: this.handleAddPaymentSourceClick, className: classes.addPaymentSourceButton }, AddCardButtonProps), Strings.addPaymentSource)) : null;
        return (React.createElement("div", { className: classes.root },
            this.renderCardRadioGroup(),
            addPaymentSourceButton,
            this.renderPaymentForm(),
            React.createElement(AlertDialog, { open: alertOpen, title: Strings.alert.title, message: Strings.alert.message, actionText: Strings.alert.button, onClose: this.handleAlertClose })));
    };
    return PaymentSourcesSelect;
}(React.Component));
export default withStyles(styles)(PaymentSourcesSelect);
//# sourceMappingURL=PaymentSourcesSelect.js.map